﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;

namespace CheckedRows_Collection
{
    public partial class Form1 : Form
    {
        #region Private Members

        List<UltraGridRow> checkedRows = new List<UltraGridRow>();

        #endregion // Private Members

        #region Constructor
        public Form1()
        {
            InitializeComponent();
        }
        #endregion // Constructor

        #region Event Handlers

        #region ultraGrid1_InitializeLayout
        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // Store some useful objects. 
            UltraGridLayout layout = e.Layout;
            UltraGridBand band = layout.Bands[0];
            UltraGridOverride ov = layout.Override;

            // Turn off the grid's built-in selection
            ov.SelectTypeRow = SelectType.None;

            // Reset the default ActiveRow and ActiveCell appearances so the ActiveRow
            // does't confuse things by appearing selected. 
            ov.ActiveRowAppearance.Reset();
            ov.ActiveCellAppearance.Reset();

            // Add an unbound Checkbox column to the grid. 
            UltraGridColumn checkBoxColumn = band.Columns.Insert(0, "CheckBox");
            checkBoxColumn.DataType = typeof(bool);

            // Create an appearance for the selected (checked) rows. 
            Infragistics.Win.Appearance checkedRowAppearance = layout.Appearances.Add("CheckBox");
            checkedRowAppearance.BackColor = SystemColors.Highlight;
            checkedRowAppearance.ForeColor = SystemColors.HighlightText;

        }
        #endregion // ultraGrid1_InitializeLayout

        #region ultraGrid1_CellChange
        private void ultraGrid1_CellChange(object sender, CellEventArgs e)
        {
            // When the checkbox is changed, maintain the CheckedRows collection
            // and update the appearance of the row. 
            if (e.Cell.Column.Key == "CheckBox")
            {
                this.CellChecked(e.Cell);
                this.UpdateRowAppearance(e.Cell.Row);
            }
        }
        #endregion // ultraGrid1_CellChange

        #region ultraGrid1_InitializeRow
        private void ultraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            // Update the appearance of the row based on the checked state. We need to do this
            // here in InitializeRow just in case there are any rows checked initially or in code. 
            this.UpdateRowAppearance(e.Row);
        }
        #endregion // ultraGrid1_InitializeRow

        #endregion // Event Handlers


        #region Private Methods

        #region CellChecked
        private void CellChecked(UltraGridCell cell)
        {
            // Maintain the checkedRows collection so we can easily access
            // the checked rows at any time. 
            if (cell.Column.Key == "CheckBox")
            {
                bool isChecked = bool.Parse(cell.Text);
                if (isChecked)
                    this.checkedRows.Add(cell.Row);
                else
                    this.checkedRows.Remove(cell.Row);
            }

            // Populate the ListBox with the currently-checked items. 
            this.listBox1.Items.Clear();
            foreach (UltraGridRow row in this.checkedRows)
            {
                this.listBox1.Items.Add(row.Cells["Column 0"].Text);
            }
        }
        #endregion // CellChecked
        
        #region UpdateRowAppearance
        private void UpdateRowAppearance(UltraGridRow row)
        {
            // Apply an appearance to the row if it's checked. 
            if (row.Cells.Exists("CheckBox"))
            {
                bool isChecked = bool.Parse(row.Cells["CheckBox"].Text);
                if (isChecked)
                    row.Appearance = row.Band.Layout.Appearances["CheckBox"];
                else
                    row.Appearance = null;
            }
        }
        #endregion // UpdateRowAppearance

        #endregion // Private Methods
    }
}
